@@ -78,6 +78,7 @@ import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 import org.apache.commons.logging.Log;
 import org.osgi.framework.BundleContext;
+import com.damienmiller.BCrypt;
 import com.openexchange.admin.exceptions.OXGenericException;
 import com.openexchange.admin.properties.AdminProperties;
 import com.openexchange.admin.rmi.dataobjects.Context;
@@ -201,8 +202,6 @@ public class AdminCache {
 
     public static final String PATTERN_REGEX_FUNCTION = "CREATE\\s+(FUNCTION|PROCEDURE) (.*?)END\\s*//";
 
-    private final Properties fallback_access_combinations = new Properties();
-
     private HashMap<String, UserModuleAccess> named_access_combinations = null;
 
     public AdminCache() {
@@ -225,7 +224,7 @@ public class AdminCache {
      *
      * @return
      */
-    public UserModuleAccess getDefaultUserModuleAccess() {
+    public static UserModuleAccess getDefaultUserModuleAccess() {
         final UserModuleAccess ret = new UserModuleAccess();
         ret.disableAll();
         ret.setWebmail(true);
@@ -354,7 +353,7 @@ public class AdminCache {
         }
     }
 
-    private Properties loadAccessCombinations() {
+    private static Properties loadAccessCombinations() {
         // Load properties from file , if does not exists use fallback
         // properties!
         final ConfigurationService service = AdminServiceRegistry.getInstance().getService(ConfigurationService.class);
@@ -364,15 +363,6 @@ public class AdminCache {
         return service.getFile("ModuleAccessDefinitions.properties");
     }
 
-    private Properties getFallbackAccessCombinations() {
-        // here we init the fallback access combinations when the file is not
-        // present.
-        fallback_access_combinations.put("basic", "contacts,webmail");
-        fallback_access_combinations.put("premium", "contacts,webmail,calendar,publicfolder");
-        fallback_access_combinations.put("standard", "contacts,webmail,calendar");
-        return fallback_access_combinations;
-    }
-
     protected void initPool() {
         this.pool = new OXAdminPoolDBPool();
     }
@@ -487,7 +477,7 @@ public class AdminCache {
         return ox_queries_initial;
     }
 
-    public Connection getSimpleSqlConnection(String url, String user, String password, String driver) throws SQLException, ClassNotFoundException {
+    public static Connection getSimpleSqlConnection(String url, String user, String password, String driver) throws SQLException, ClassNotFoundException {
         // System.err.println("-->"+driver+" ->"+url+" "+user+" "+password);
         Class.forName(driver);
         // give database some time to react (in seconds)
@@ -583,7 +573,7 @@ public class AdminCache {
         return al;
     }
 
-    private String[] getOrdered(String data) {
+    private static String[] getOrdered(String data) {
         String[] ret = new String[0];
         if (data != null) {
             StringTokenizer st = new StringTokenizer(data, ",");
@@ -629,26 +619,32 @@ public class AdminCache {
      * @throws UnsupportedEncodingException
      */
     public String encryptPassword(final PasswordMechObject user) throws StorageException, NoSuchAlgorithmException, UnsupportedEncodingException {
-        String passwd = null;
-        if (user.getPasswordMech() == null) {
+        String passwordMech = user.getPasswordMech();
+        if (passwordMech == null) {
             String pwmech = getProperties().getUserProp(AdminProperties.User.DEFAULT_PASSWORD_MECHANISM, "SHA");
             pwmech = "{" + pwmech + "}";
             if (pwmech.equalsIgnoreCase(PasswordMechObject.CRYPT_MECH)) {
-                user.setPasswordMech(PasswordMechObject.CRYPT_MECH);
+                passwordMech = PasswordMechObject.CRYPT_MECH;
             } else if (pwmech.equalsIgnoreCase(PasswordMechObject.SHA_MECH)) {
-                user.setPasswordMech(PasswordMechObject.SHA_MECH);
+                passwordMech = PasswordMechObject.SHA_MECH;
+            } else if (pwmech.equalsIgnoreCase(PasswordMechObject.BCRYPT_MECH)) {
+                passwordMech = PasswordMechObject.BCRYPT_MECH;
             } else {
                 log.warn("WARNING: unknown password mechanism " + pwmech + " using SHA");
-                user.setPasswordMech(PasswordMechObject.SHA_MECH);
+                passwordMech = PasswordMechObject.SHA_MECH;
             }
         }
-        if (user.getPasswordMech().equals(PasswordMechObject.CRYPT_MECH)) {
+        user.setPasswordMech(passwordMech);
+        final String passwd;
+        if (PasswordMechObject.CRYPT_MECH.equals(passwordMech)) {
             passwd = UnixCrypt.crypt(user.getPassword());
-        } else if (user.getPasswordMech().equals(PasswordMechObject.SHA_MECH)) {
+        } else if (PasswordMechObject.SHA_MECH.equals(passwordMech)) {
             passwd = SHACrypt.makeSHAPasswd(user.getPassword());
+        } else if (PasswordMechObject.BCRYPT_MECH.equals(passwordMech)) {
+            passwd = BCrypt.hashpw(user.getPassword(), BCrypt.gensalt());
         } else {
-            log.error("unsupported password mechanism: " + user.getPasswordMech());
-            throw new StorageException("unsupported password mechanism: " + user.getPasswordMech());
+            log.error("unsupported password mechanism: " + passwordMech);
+            throw new StorageException("unsupported password mechanism: " + passwordMech);
         }
         return passwd;
     }
@@ -754,5 +750,4 @@ public class AdminCache {
     public boolean isMasterAdmin(final Credentials auth) {
         return masterAuthenticationDisabled || (getMasterCredentials() != null && getMasterCredentials().getLogin().equals(auth.getLogin()));
     }
-
 }
